pub struct Lexer<'src> { /* private fields */ }Expand description
The Bock lexer: advances through a SourceFile and produces a token stream.
Implementations
Sourceimpl<'src> Lexer<'src>
impl<'src> Lexer<'src>
Sourcepub fn new(source: &'src SourceFile) -> Self
pub fn new(source: &'src SourceFile) -> Self
Create a new Lexer for the given source file.
Sourcepub fn tokenize(&mut self) -> Vec<Token>
pub fn tokenize(&mut self) -> Vec<Token>
Tokenize the entire source file, returning all tokens including a final TokenKind::Eof.
Sourcepub fn diagnostics(&self) -> &DiagnosticBag
pub fn diagnostics(&self) -> &DiagnosticBag
Access the accumulated diagnostics.